import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '类型',
    dataIndex: 'category',
    width: 120,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 140,
  },
];
export const SearchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'isKinship',
    component: 'Checkbox',
    label: '仅看血缘对象',
    colProps: { span: 8 },
    labelWidth: 120,
  },
];
export const storageManagementColumns: BasicColumn[] = [
  {
    title: '参数名',
    dataIndex: 'parameterName',
    width: 120,
  },
  {
    title: '参数类型',
    dataIndex: 'parameterType',
    edit: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '时间类',
          value: '1',
        },
        {
          label: '字符类',
          value: '2',
        },
        {
          label: '数值类',
          value: '3',
        },
        {
          label: '自定义类',
          value: '4',
        },
      ],
    },
    width: 200,
  },
  {
    title: '参数值',
    dataIndex: 'parameterValue',
    width: 80,
    editable: true,
    edit: true,
  },
];
export const storageManagementFormSchema: FormSchema[] = [
  {
    field: 'keyword',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '请输入关键字搜索',
    },
    colProps: { lg: 8, md: 4 },
  },
];
export const storageManagementData: any[] = [
  {
    id: '1',
    startTime: '2024-10-01 08:00:00',
    endTime: '2024-10-01 10:30:00',
    useTime: '2小时30分钟',
    status: '1',
    type: '手动清理',
    pointNum: '5000',
    num: '2000',
    user: '张三',
    parameterName: 'check_date',
    parameterType: '字符类',
    parameterValue: '参数值',
  },
  {
    id: '2',
    startTime: '2024-10-02 09:00:00',
    endTime: '2024-10-02 11:45:00',
    useTime: '2小时45分钟',
    status: '0',
    type: '自动清理',
    pointNum: '7000',
    num: '3500',
    user: '李四',
    parameterName: 'check_date',
    parameterType: '时间类',
    parameterValue: '参数值',
  },
  {
    id: '3',
    startTime: '2024-10-03 10:00:00',
    endTime: '2024-10-03 12:15:00',
    useTime: '2小时15分钟',
    status: '1',
    type: '手动清理',
    pointNum: '6000',
    num: '3000',
    user: '王五',
    parameterName: 'check_date',
    parameterType: '数值类',
    parameterValue: '参数值',
  },
  {
    id: '4',
    startTime: '2024-10-04 11:00:00',
    endTime: '2024-10-04 13:20:00',
    useTime: '2小时20分钟',
    status: '1',
    type: '自动清理',
    pointNum: '4500',
    num: '2250',
    user: '赵六',
    parameterName: 'check_date',
    parameterType: '自定义类',
    parameterValue: '参数值',
  },
  {
    id: '5',
    startTime: '2024-10-05 12:00:00',
    endTime: '2024-10-05 14:30:00',
    useTime: '2小时30分钟',
    status: '1',
    type: '手动清理',
    pointNum: '5500',
    num: '2750',
    user: '孙七',
    parameterName: 'check_date',
    parameterType: '数值类',
    parameterValue: '参数值',
  },
];
export const storageManagementBasicFormSchema: FormSchema[] = [
  // {
  //   field: 'field12',
  //   component: 'BasicTitle',
  //   label: '规则展示',
  //   componentProps: {
  //     // line: true,
  //     span: true,
  //   },
  //   colProps: {
  //     span: 24,
  //   },
  // },
  {
    field: 'ruleName',
    component: 'Input',
    label: '规则名称',
    required: true,
    componentProps: {},
    colProps: {
      span: 24,
    },
  },
  {
    field: 'description',
    component: 'InputTextArea',
    label: '描述',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'status',
    component: 'Switch',
    label: '规则状态',
    componentProps: {},
    colProps: {
      span: 12,
    },
  },
  {
    field: 'resourceType',
    component: 'Select',
    label: '资源类型',
    componentProps: {
      defaultValue: '1',
      options: [
        { label: '工作流', value: '1' },
        { label: '工作流', value: '2' },
      ],
    },
    colProps: {
      span: 16,
    },
  },
  {
    field: 'resourceId',
    component: 'CheckboxGroup',
    label: '触发方式',
    required: true,
    componentProps: {
      options: [
        { label: '运行失败', value: '1' },
        { label: '运行成功', value: '2' },
        { label: '开始运行', value: '3' },
        { label: '运行超时', value: '4' },
      ],
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'timeOut',
    component: 'InputNumber',
    label: '超时时长',
    ifShow: ({ values }) => values.resourceId !== undefined && values.resourceId.includes('4'),
    required: ({ values }) => values.resourceId !== undefined && values.resourceId.includes('4'),
    componentProps: {
      min: 0,
    },
    suffix: '分钟',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'alarmType',
    component: 'CheckboxGroup',
    label: '通知方式',
    required: true,
    componentProps: {
      options: [
        { label: '站内信', value: '1' },
        { label: '邮件', value: '2' },
        { label: '短信', value: '3' },
      ],
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'zhanneixin',
    component: 'Input',
    label: '站内信',
    ifShow: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('1'),
    required: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('1'),
    componentProps: {},
    colProps: {
      span: 24,
    },
  },
  {
    field: 'email',
    label: '邮箱地址',
    component: 'InputTextArea',
    colProps: { span: 24 },
    componentProps: {
      defaultValue: '11111112222222@123321.123',
      placeholder: '多个邮件地址用;分隔符分割',
    },
    ifShow: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('2'),
    required: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('2'),
  },
  {
    field: 'sms',
    label: '短信号码',
    component: 'InputTextArea',
    colProps: { span: 24 },
    componentProps: {
      defaultValue: '123321.123',
      placeholder: '多个短信号码用;分隔符分割',
    },
    ifShow: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('3'),
    required: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('3'),
  },
];
