import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user'; // 引入开关组件
type CheckedType = boolean | string | number;

export const columns: BasicColumn[] = [
  {
    title: '质量主体名称',
    dataIndex: 'fileName',
    width: 150,
    slots: { customRender: 'fileName' },
  },
  {
    title: '描述',
    dataIndex: 'descripe',
    width: 150,
  },
  {
    title: '创建者',
    dataIndex: 'holder',
    width: 150,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '原始主体',
    dataIndex: 'originalPrincipal',
    slots: { customRender: 'originalPrincipal' },
    width: 150,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入名称',
    },
    colProps: { span: 7 },
  },
];
export const accountFormSchema: any[] = [
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'location',
    label: '保存位置',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'createDate',
    label: '创建时间',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
  {
    field: 'updateDate',
    label: '最近修改',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      disabled: true,
    },
  },
];

/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];

/**存储管理*/
export const StorageSchema: FormSchema[] = [
  {
    field: 'isStorage',
    label: '存储主体问题数据明细',
    component: 'Checkbox',
    colProps: { lg: 12, md: 24 },
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        formActionType.updateSchema([{ field: 'isStorageInHDFS', ifShow: formModel.isStorage }]);
        formActionType.updateSchema([{ field: 'handle', ifShow: formModel.isStorage }]);
        formActionType.updateSchema([{ field: 'isAutoClear', ifShow: formModel.isStorage }]);
        formActionType.updateSchema([{ field: 'clear', ifShow: formModel.isStorage }]);
        formActionType.updateSchema([{ field: 'divider', ifShow: formModel.isStorage }]);
      },
    }),
  },
  {
    field: 'isStorageInHDFS',
    label: '存储到HDFS',
    labelWidth: 85,
    component: 'Checkbox',
    colProps: { lg: 12, md: 24 },
    ifShow: false,
  },
  {
    field: 'handle',
    label: '手动清理',
    component: 'BasicTitle',
    ifShow: false,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'clear',
    label: '清理',
    component: 'Input',
    labelWidth: 30,
    colProps: { lg: 24, md: 24 },
    ifShow: false,
    slot: 'clear',
  },
  {
    field: 'divider',
    component: 'Divider',
    ifShow: false,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'isAutoClear',
    label: '自动清理',
    labelWidth: 70,
    component: 'Checkbox',
    colProps: { lg: 12, md: 24 },
    ifShow: false,
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        formActionType.updateSchema([{ field: 'maxRetentionTime', ifShow: formModel.isAutoClear }]);
        formActionType.updateSchema([{ field: 'inspectionCycle', ifShow: formModel.isAutoClear }]);
        formActionType.updateSchema([{ field: 'inspectionTime', ifShow: formModel.isAutoClear }]);
      },
    }),
  },
  {
    field: 'maxRetentionTime',
    label: '最长保留时间',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      addonAfter: '天',
    },
    ifShow: false,
  },

  {
    field: 'inspectionCycle',
    label: '检查周期',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '每天', value: '每天' },
        { label: '每周', value: '每周' },
        { label: '每月', value: '每月' },
        { label: '每年', value: '每年' },
      ],
    },
    ifShow: false,
  },
  {
    field: 'inspectionTime',
    label: '检查时间',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    ifShow: false,
    slot: 'isStorageInHDFS',
  },
];

export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
    colProps: { span: 8 },
  },
];
export const createFileFormSchema: FormSchema[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'fileName',
    label: '文件名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文件名称',
    },
  },
];
export const createTaskFormSchema: FormSchema[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'fileName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'name',
    label: '质量主体名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入质量主体名称',
      },
    ],
    componentProps: {
      placeholder: '请输入质量主体名称',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fileType',
    label: '文件类型',
    component: 'Input',
    defaultValue: '质量主体',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
];
