import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user'; // 引入开关组件
type CheckedType = boolean | string | number;

export const columns: BasicColumn[] = [
  {
    title: '姓名',
    dataIndex: 'name',
    width: 150,
  },
  {
    title: '登录名',
    dataIndex: 'username',
    width: 150,
  },
  {
    title: '用户角色',
    dataIndex: 'roleName',
    width: 150,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '姓名',
    component: 'Input',
    componentProps: {
      placeholder: '请输入姓名',
    },
    colProps: { span: 7 },
  },
  {
    field: 'username',
    label: '登录名',
    component: 'Input',
    componentProps: {
      placeholder: '请输入登录名',
    },
    colProps: { span: 7 },
  },
];

export const TreeData: any[] = [
  {
    delFlag: '0',
    flag: '1',
    businessId: 100,
    fileName: '质量白名单',
    anotherName: '质量白名单',
    parentId: 0,
    'code:': '001',
    ancestors: '0',
    orderNum: 0,
    selectType: null,
    location: '/质量主体',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    icon: 'ant-design:partition-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 101,
    fileName: 'DMP_admin-个人工作区',
    anotherName: 'DMP_admin-个人工作区',
    parentId: 100,
    'code:': '002',
    ancestors: '0,100',
    orderNum: 1,
    selectType: null,
    location: '/质量主体/DMP_admin-个人工作区',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    icon: 'ant-design:folder-open-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 102,
    fileName: '共享工作区',
    anotherName: '共享工作区',
    parentId: 100,
    'code:': '002',
    ancestors: '0,100',
    orderNum: 1,
    selectType: null,
    location: '/质量主体/共享工作区',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    icon: 'ant-design:folder-open-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 201,
    fileName: '贫困毕业生',
    anotherName: '贫困毕业生',
    parentId: 101,
    'code:': '005',
    ancestors: '0,100,101',
    orderNum: 2,
    selectType: null,
    location: '/质量主体/DMP_admin-个人工作区/贫困毕业生',
    holder: 'admin',
    createDate: '2024-10-22 8:04:04',
    updateDate: '2024-10-22 8:04:04',
    icon: 'ant-design:partition-outlined',
    originalPrincipal: '贫困毕业生',
    dimensionCodeColumn: 'code',
    questionTablePrefix: 'quailty_',
    dimensionMeaningColumn: 'code',
    sql:
      'SELECT COUNT(*)\n' +
      'FROM $(table a}\n' +
      'WHERE ${column a}IS NOT NULL AND ${column a}NOT IN (${range a})',
    isIndependent: true,
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 202,
    fileName: 'test',
    anotherName: 'test',
    parentId: 101,
    'code:': '006',
    ancestors: '0,100,101',
    orderNum: 3,
    selectType: null,
    location: '/质量主体/DMP_admin-个人工作区/test',
    holder: 'admin',
    createDate: '2024-10-21 9:04:04',
    updateDate: '2024-10-21 9:04:04',
    icon: 'ant-design:partition-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 203,
    fileName: 'sql_test',
    anotherName: 'sql_test',
    parentId: 101,
    'code:': '008',
    ancestors: '0,100,101',
    orderNum: 5,
    selectType: null,
    location: '/质量主体/DMP_admin-个人工作区/sql_test',
    holder: 'admin',
    createDate: '2024-10-23 12:04:04',
    updateDate: '2024-10-23 12:04:04',
    originalPrincipal: '贫困毕业生',
    dimensionCodeColumn: 'code',
    questionTablePrefix: 'quailty_',
    dimensionMeaningColumn: 'code',
    icon: 'ant-design:partition-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 204,
    fileName: '质量主体1',
    anotherName: '质量主体1',
    parentId: 102,
    'code:': '008',
    ancestors: '0,100,101',
    orderNum: 5,
    selectType: null,
    location: '/质量主体/共享工作区/质量主体1',
    holder: 'admin',
    createDate: '2024-10-23 12:04:04',
    updateDate: '2024-10-23 12:04:04',
    originalPrincipal: '贫困毕业生',
    dimensionCodeColumn: 'code',
    questionTablePrefix: 'quailty_',
    dimensionMeaningColumn: 'code',
    icon: 'ant-design:partition-outlined',
  },
];
export const fileData: any[] = [
  {
    delFlag: '0',
    flag: '1',
    businessId: 300,
    username: 'file1',
    nickName: '测试文件流1',
    name: '测试文件流1',
    fileSize: 1024,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    institutionId: 105,
    institutionName: '财务部门',
    menuList: [],
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 301,
    username: 'file2',
    nickName: '测试文件流2',
    name: '测试文件流2',
    fileSize: 1024,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    institutionId: 105,
    institutionName: '财务部门',
    menuList: [],
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 302,
    username: 'file3',
    nickName: '测试文件流3',
    name: '测试文件流3',
    fileSize: 1024,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    institutionId: 105,
    institutionName: '财务部门',
    menuList: [],
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 303,
    username: 'file4',
    nickName: '测试文件流4',
    name: '测试文件流4',
    fileSize: 1024,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    institutionId: 105,
    institutionName: '财务部门',
    menuList: [],
  },
];

export const infoData: any[] = [
  {
    tableName: 'st',
    columnsName: 'user_id',
    CNname: '用户ID',
    type: 'INT',
    length: 11,
    precision: null,
    isNull: 'NO',
    remark: '用户的唯一标识符',
    primaryKey: 'YES',
    foreignKey: 'NO',
    dataType: '整数型',
    safeLevel: '高',
    sensitiveStatus: '敏感',
    isFixation: 'true',
  },
  {
    tableName: 'st',
    columnsName: 'username',
    CNname: '用户名',
    type: 'VARCHAR',
    length: 50,
    precision: null,
    isNull: 'NO',
    remark: '用户的登录名称',
    primaryKey: 'NO',
    foreignKey: 'NO',
    dataType: '字符串型',
    safeLevel: '中',
    sensitiveStatus: '非敏感',
    isFixation: 'true',
  },
  {
    tableName: 'st',
    columnsName: 'password',
    CNname: '密码',
    type: 'VARCHAR',
    length: 100,
    precision: null,
    isNull: 'NO',
    remark: '用户登录密码（加密存储）',
    primaryKey: 'NO',
    foreignKey: 'NO',
    dataType: '字符串型',
    safeLevel: '极高',
    sensitiveStatus: '非常敏感',
    isFixation: 'true',
  },
  {
    tableName: 'st',
    columnsName: 'email',
    CNname: '邮箱地址',
    type: 'VARCHAR',
    length: 100,
    precision: null,
    isNull: 'YES',
    remark: '用户注册邮箱地址',
    primaryKey: 'NO',
    foreignKey: 'NO',
    dataType: '字符串型',
    safeLevel: '中',
    sensitiveStatus: '敏感',
    isFixation: 'true',
  },
  {
    tableName: 'st',
    columnsName: 'created_at',
    CNname: '创建时间',
    type: 'DATETIME',
    length: null,
    precision: null,
    isNull: 'NO',
    remark: '账户创建的时间戳',
    primaryKey: 'NO',
    foreignKey: 'NO',
    dataType: '日期时间型',
    safeLevel: '低',
    sensitiveStatus: '非敏感',
    isFixation: 'false',
  },
  {
    tableName: 'st',
    columnsName: 'updated_at',
    CNname: '最后更新时间',
    type: 'DATETIME',
    length: null,
    precision: null,
    isNull: 'YES',
    remark: '账户信息最后更新的时间戳',
    primaryKey: 'NO',
    foreignKey: 'NO',
    dataType: '日期时间型',
    safeLevel: '低',
    sensitiveStatus: '非敏感',
    isFixation: 'true',
  },
  {
    tableName: 'st',
    columnsName: 'is_active',
    CNname: '账户状态',
    type: 'TINYINT',
    length: 1,
    precision: null,
    isNull: 'NO',
    remark: '账户是否处于激活状态（0-未激活，1-已激活）',
    primaryKey: 'NO',
    foreignKey: 'NO',
    dataType: '布尔型',
    safeLevel: '中',
    sensitiveStatus: '非敏感',
    isFixation: 'true',
  },
  {
    tableName: 'st',
    columnsName: 'is_deleted',
    CNname: '删除标记',
    type: 'TINYINT',
    length: 1,
    precision: null,
    isNull: 'NO',
    remark: '账户是否被标记为删除（0-未删除，1-已删除）',
    primaryKey: 'NO',
    foreignKey: 'NO',
    dataType: '布尔型',
    safeLevel: '中',
    sensitiveStatus: '非敏感',
    isFixation: 'true',
  },
];

export const associationRulesData: any[] = [
  {
    ruleName: '最低成绩',
    template: '学生成绩校验',
    keyField: 'score',
    described: '最低成绩不能低于60',
  },
  {
    ruleName: '青少年',
    template: '年龄限制',
    keyField: 'age',
    described: '年龄小于18',
  },
  {
    ruleName: '规则1',
    template: '质量模板1',
    keyField: 'cloums1',
    described: '规则描述1',
  },
  {
    ruleName: '规则2',
    template: '质量模板2',
    keyField: 'cloums2',
    described: '规则描述2',
  },
];

export const reviewData: any[] = [
  {
    age: 23,
    id: 4,
    name: '戴瑞灰',
    score: 92,
    sex: '男',
  },
  {
    age: 30,
    id: 8,
    name: '康再溪',
    score: 60,
    sex: '女',
  },
  {
    age: 23,
    id: 1,
    name: '田欣慧',
    score: 100,
    sex: '女',
  },
  {
    age: 18,
    id: 5,
    name: '宋艳',
    score: 99,
    sex: '女',
  },
];
export const accountFormSchema: any[] = [];
