import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入关键字',
    },
  },
  {
    field: 'sort',
    label: ' ',
    component: 'Select',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '模块',
      options: [
        { label: '数据指标', value: '数据指标' },
        { label: '质量主体', value: '质量主体' },
      ],
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '主体名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '模块',
    dataIndex: 'module',
    width: 120,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 120,
  },

];

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名称',
      },
    ],
  },
  {
    field: 'describe',
    component: 'InputTextArea',
    label: '描述',
    componentProps: {
      placeholder: '请输入描述',
      rows: 4,
    },
  },
  {
    field: 'sort',
    label: '最低安全分级',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择推荐保护动作',
      },
    ],
  },
  {
    field: 'protectAction',
    label: '推荐脱敏算法',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'BlockFront', value: 'BlockFront' },
        { label: 'Delete', value: 'Delete' },
        { label: 'Mask', value: 'Mask' },
        { label: 'Base64', value: 'Base64' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择推荐保护动作',
      },
    ],
  },
  {
    field: 'params',
    label: '算法参数',
    component: 'Input',

  },


]
